@@ -38,9 +38,6 @@
 
 #include <utils/gnupg-helper.h>
 
-#include <QGpgME/Protocol>
-#include <QGpgME/CryptoConfig>
-
 #include <gpgme++/key.h>
 
 #include <KLocalizedString>
@@ -50,16 +47,6 @@ using namespace Kleo;
 using namespace Kleo::Commands;
 using namespace GpgME;
 
-static bool haveKeyserverConfigured()
-{
-    const QGpgME::CryptoConfig *const config = QGpgME::cryptoConfig();
-    if (!config) {
-        return false;
-    }
-    const QGpgME::CryptoConfigEntry *const entry = config->entry(QStringLiteral("gpg"), QStringLiteral("Keyserver"), QStringLiteral("keyserver"));
-    return entry && !entry->stringValue().isEmpty();
-}
-
 ExportOpenPGPCertsToServerCommand::ExportOpenPGPCertsToServerCommand(KeyListController *c)
     : GnuPGProcessCommand(c)
 {
@@ -140,7 +127,7 @@ QString ExportOpenPGPCertsToServerCommand::crashExitMessage(const QStringList &a
     return xi18nc("@info",
                   "<para>The GPG process that tried to export OpenPGP certificates "
                   "ended prematurely because of an unexpected error.</para>"
-                  "<para>Please check the output of <icode>%1</icode> for details.</para>", args.join(QStringLiteral(" ")));
+                  "<para>Please check the output of <icode>%1</icode> for details.</para>", args.join(QLatin1Char(' ')));
 }
 
 QString ExportOpenPGPCertsToServerCommand::errorExitMessage(const QStringList &args) const
