@@ -87,19 +87,22 @@ static void resetDefaults()
         return;
     }
 
-    for (const auto &compName: config->componentList()) {
+    const QStringList componentList = config->componentList();
+    for (const auto &compName: componentList) {
         auto comp = config->component(compName);
         if (!comp) {
             qCWarning(KLEOPATRA_LOG) << "Failed to find component:" << comp;
             return;
         }
-        for (const auto &grpName: comp->groupList()) {
+        const QStringList groupList = comp->groupList();
+        for (const auto &grpName: groupList) {
             auto grp = comp->group(grpName);
             if (!grp) {
                 qCWarning(KLEOPATRA_LOG) << "Failed to find group:" << grp << "in component:" << compName;
                 return;
             }
-            for (const auto &entryName: grp->entryList()) {
+            const QStringList entries = grp->entryList();
+            for (const auto &entryName: entries) {
                 auto entry = grp->entry(entryName);
                 if (!entry) {
                     qCWarning(KLEOPATRA_LOG) << "Failed to find entry:" << entry << "in group:"<< grp << "in component:" << compName;
@@ -295,17 +298,9 @@ void CryptoOperationsConfigWidget::setupGui()
 
     connect(mQuickSignCB, &QCheckBox::toggled, this, &CryptoOperationsConfigWidget::changed);
     connect(mQuickEncryptCB, &QCheckBox::toggled, this, &CryptoOperationsConfigWidget::changed);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mChecksumDefinitionCB, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
-#else
-    connect(mChecksumDefinitionCB, static_cast<void (QComboBox::*)(int, const QString &)>(&QComboBox::currentIndexChanged) ,
-#endif
             this, &CryptoOperationsConfigWidget::changed);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mArchiveDefinitionCB, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
-#else
-    connect(mArchiveDefinitionCB, static_cast<void (QComboBox::*)(int, const QString &)>(&QComboBox::currentIndexChanged) ,
-#endif
             this, &CryptoOperationsConfigWidget::changed);
     connect(mPGPFileExtCB, &QCheckBox::toggled, this, &CryptoOperationsConfigWidget::changed);
     connect(mAutoDecryptVerifyCB, &QCheckBox::toggled, this, &CryptoOperationsConfigWidget::changed);
