@@ -33,9 +33,9 @@
 #include "commands/dumpcertificatecommand.h"
 #include "utils/remarks.h"
 
-#include <libkleo/formatting.h>
-#include <libkleo/dn.h>
-#include <libkleo/keycache.h>
+#include <Libkleo/Formatting>
+#include <Libkleo/Dn>
+#include <Libkleo/KeyCache>
 
 #include <gpgme++/context.h>
 #include <gpgme++/key.h>
@@ -69,7 +69,7 @@ class CertificateDetailsWidget::Private
 {
 public:
     Private(CertificateDetailsWidget *parent)
-        : q(parent)
+        : updateInProgress (false), q(parent)
     {}
 
     void setupCommonProperties();
@@ -103,7 +103,7 @@ public:
     GpgME::Key key;
     bool updateInProgress;
 private:
-    CertificateDetailsWidget *q;
+    CertificateDetailsWidget *const q;
 };
 
 void CertificateDetailsWidget::Private::setupCommonProperties()
