@@ -53,8 +53,8 @@ class SelfTestDialog : public QDialog
     Q_OBJECT
     Q_PROPERTY(bool runAtStartUp READ runAtStartUp WRITE setRunAtStartUp)
 public:
-    explicit SelfTestDialog(QWidget *parent = nullptr, Qt::WindowFlags f = 0);
-    explicit SelfTestDialog(const std::vector<std::shared_ptr<SelfTest>> &tests, QWidget *parent = nullptr, Qt::WindowFlags f = 0);
+    explicit SelfTestDialog(QWidget *parent = nullptr, Qt::WindowFlags f = {});
+    explicit SelfTestDialog(const std::vector<std::shared_ptr<SelfTest>> &tests, QWidget *parent = nullptr, Qt::WindowFlags f = {});
     ~SelfTestDialog();
 
     void setAutomaticMode(bool automatic);
