@@ -67,7 +67,7 @@ public:
 
         if (!hasFeature(AssuanEngineFeature, 0)) {
             m_error = i18n("GpgME library too old");
-            m_explaination = i18nc("@info",
+            m_explanation = i18nc("@info",
                                    "Either the GpgME library itself is too old, "
                                    "or the GpgME++ library was compiled against "
                                    "an older GpgME that did not support connecting to gpg-agent.");
@@ -86,7 +86,7 @@ public:
             const std::unique_ptr<Context> ctx = Context::createForEngine(AssuanEngine, &error);
             if (!ctx.get()) {
                 m_error = i18n("GpgME does not support gpg-agent");
-                m_explaination = xi18nc("@info",
+                m_explanation = xi18nc("@info",
                                         "<para>The <application>GpgME</application> library is new "
                                         "enough to support <application>gpg-agent</application>, "
                                         "but does not seem to do so in this installation.</para>"
@@ -101,7 +101,7 @@ public:
                 if (error) {
                     m_passed = false;
                     m_error = i18n("unexpected error");
-                    m_explaination = xi18nc("@info",
+                    m_explanation = xi18nc("@info",
                                             "<para>Unexpected error while asking <application>gpg-agent</application> "
                                             "for its version.</para>"
                                             "<para>The error returned was: <message>%1</message>.</para>",
