@@ -57,15 +57,16 @@ using namespace Kleo;
 using namespace Kleo::SmartCard;
 using namespace Kleo::Commands;
 
-NetKeyWidget::NetKeyWidget() :
-    mSerialNumber(new QLabel),
-    mVersionLabel(new QLabel),
-    mLearnKeysLabel(new QLabel),
-    mErrorLabel(new QLabel),
+NetKeyWidget::NetKeyWidget(QWidget *parent) :
+    QWidget(parent),
+    mSerialNumber(new QLabel(this)),
+    mVersionLabel(new QLabel(this)),
+    mLearnKeysLabel(new QLabel(this)),
+    mErrorLabel(new QLabel(this)),
     mNullPinWidget(new NullPinWidget()),
-    mLearnKeysBtn(new QPushButton),
-    mChangeNKSPINBtn(new QPushButton),
-    mChangeSigGPINBtn(new QPushButton),
+    mLearnKeysBtn(new QPushButton(this)),
+    mChangeNKSPINBtn(new QPushButton(this)),
+    mChangeSigGPINBtn(new QPushButton(this)),
     mTreeView(new KeyTreeView(this)),
     mArea(new QScrollArea)
 {
@@ -172,6 +173,10 @@ NetKeyWidget::NetKeyWidget() :
     vLay->addStretch(1);
 }
 
+NetKeyWidget::~NetKeyWidget()
+{
+}
+
 void NetKeyWidget::setCard(const NetKeyCard* card)
 {
     mVersionLabel->setText(i18nc("1 is a Version number", "NetKey v%1 Card", card->appVersion()));
@@ -200,7 +205,7 @@ void NetKeyWidget::setCard(const NetKeyCard* card)
 
     const auto errMsg = card->errorMsg();
     if (!errMsg.isEmpty()) {
-        mErrorLabel->setText(QStringLiteral("<b>%1:</b> %2").arg(i18n("Error")).arg(errMsg));
+        mErrorLabel->setText(QStringLiteral("<b>%1:</b> %2").arg(i18n("Error"), errMsg));
         mErrorLabel->setVisible(true);
     } else {
         mErrorLabel->setVisible(false);
